@@ -25,7 +25,7 @@
 #'      "featureID=MD-BC-BC-05",
 #'      "offering=RAW",
 #'      "observedProperty=WATER",sep="&")
-#' \dontrun{
+#' 
 #' dataReturned1 <- importWaterML2(URL)
 #' dataReturn2 <- importWaterML2(URL2, TRUE)
 #' URLmulti <-  paste(baseURL,
@@ -39,34 +39,17 @@
 #' fileName <- "WaterML2Example.xml"
 #' fullPath <- file.path(filePath, fileName)
 #' UserData <- importWaterML2(fullPath)
-#' }
+#' 
 importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
   
   if(file.exists(obs_url)){
-    doc <- xmlTreeParse(obs_url, getDTD = FALSE, useInternalNodes = TRUE)
+    rawData <- obs_url
   } else {
-    doc = tryCatch({
-      h <- basicHeaderGatherer()
-      returnedDoc <- getURL(obs_url, headerfunction = h$update)
-      if(h$value()["Content-Type"] == "text/xml;charset=UTF-8" | 
-           h$value()["Content-Type"] == "text/xml; subtype=gml/3.1.1;charset=UTF-8"){
-        xmlTreeParse(returnedDoc, getDTD = FALSE, useInternalNodes = TRUE)
-      } else {
-        message(paste("URL caused an error:", obs_url))
-        message("Content-Type=",h$value()["Content-Type"])
-        return(NA)
-      }   
-      
-    }, warning = function(w) {
-      message(paste("URL caused a warning:", obs_url))
-      message(w)
-    }, error = function(e) {
-      message(paste("URL does not seem to exist:", obs_url))
-      message(e)
-      return(NA)
-    })
+    rawData <- getWebServiceData(obs_url)
   }
   
+  doc <- xmlTreeParse(rawData, getDTD = FALSE, useInternalNodes = TRUE)
+  
   if(tz != ""){
     tz <- match.arg(tz, c("America/New_York","America/Chicago",
                           "America/Denver","America/Los_Angeles",
@@ -81,9 +64,11 @@ importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
   
   
   timeSeries <- xpathApply(doc, "//wml2:Collection", namespaces = ns)
-  
+
   if(0 == length(timeSeries)){
-    stop("No data to return for URL:", obs_url)
+    df <- data.frame()
+    attr(df, "url") <- obs_url
+    return(df)
   }
   
   for (i in 1:length(timeSeries)){
@@ -92,13 +77,22 @@ importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
     chunk <- xmlRoot(chunk)
     chunkNS <- xmlNamespaceDefinitions(chunk, simplify = TRUE)
     
+#     xp <- xpathApply(chunk, "//wml2:MeasurementTimeseries/wml2:point/wml2:MeasurementTVP", 
+#                      xpathSApply, ".//*[not(*)]", 
+#                      function(x) setNames(ifelse(nzchar(xmlValue(x)), 
+#                                        xmlValue(x), 
+#                                           ifelse("qualifier" == xmlName(x),
+#                                                 xpathSApply(x,"./@xlink:title",namespaces = ns),"")), #originally I had the "" as xmlAttr(x) 
+#                                                     xmlName(x)), 
+#                      namespaces = chunkNS)
+    
     xp <- xpathApply(chunk, "//wml2:MeasurementTimeseries/wml2:point/wml2:MeasurementTVP", 
                      xpathSApply, ".//*[not(*)]", 
                      function(x) setNames(ifelse(nzchar(xmlValue(x)), 
                                                  xmlValue(x), 
-                                                    ifelse("qualifier" == xmlName(x),
-                                                           xpathSApply(x,"./@xlink:title",namespaces = ns),"")), #originally I had the "" as xmlAttr(x) 
-                                                            xmlName(x)), 
+                                                 ifelse("qualifier" == xmlName(x),
+                                                        xpathSApply(x,"./@xlink:title",namespaces = ns),"")), #originally I had the "" as xmlAttr(x) 
+                                          xmlName(x,full=TRUE)), 
                      namespaces = chunkNS)
   
     if(length(xpathApply(doc, 
@@ -106,9 +100,12 @@ importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
                   xmlValue, namespaces = ns)) != 0){
       xp <- xp[-1]
     }
-      
+
+    
     DF2 <- do.call(rbind.fill.matrix, lapply(xp, t))
     DF2 <- as.data.frame(DF2,stringsAsFactors=FALSE)
+
+    names(DF2)[grep("wml2",names(DF2))] <- sub("wml2:","",names(DF2)[grep("wml2",names(DF2))])
     
     if(asDateTime){
     
@@ -128,6 +125,8 @@ importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
     }
   
     DF2$value <- as.numeric(DF2$value)
+    
+#########################################
     # Very specific to USGS:
     defaultQualifier <- as.character(xpathApply(chunk, "//wml2:defaultPointMetadata/wml2:DefaultTVPMeasurementMetadata/wml2:qualifier/@xlink:title",namespaces = chunkNS))
     
@@ -135,17 +134,22 @@ importWaterML2 <- function(obs_url, asDateTime=FALSE, tz=""){
       defaultQualifier <- "NA"
     }
     
-    if("qualifier" %in% names(DF2)){
-      DF2$qualifier <- ifelse(defaultQualifier != DF2$qualifier,DF2$qualifier,defaultQualifier)
+    if("swe:value" %in% names(DF2)){
+      isQual <- as.character(xpathApply(chunk, 
+                                        "//wml2:MeasurementTimeseries/wml2:point/wml2:MeasurementTVP/wml2:metadata/wml2:TVPMeasurementMetadata/wml2:qualifier/@xlink:title",
+                                        namespaces = chunkNS))
+      DF2$qualifier <- ifelse(defaultQualifier != isQual,isQual,defaultQualifier)
+      DF2$`swe:value` <- NULL
     } else {
       DF2$qualifier <- rep(defaultQualifier,nrow(DF2))
     }
     
     
-    DF2$qualifier <- ifelse("Provisional data subject to revision." == DF2$qualifier, "P",
-                               ifelse("Approved for publication. Processing and review completed." == DF2$qualifier, "A", DF2$qualifier))
+#     DF2$qualifier <- ifelse("Provisional data subject to revision." == DF2$qualifier, "P",
+#                                ifelse("Approved for publication. Processing and review completed." == DF2$qualifier, "A", DF2$qualifier))
     
-  
+#########################################
+
     id <- as.character(xpathApply(chunk, "//gml:identifier", xmlValue, namespaces = chunkNS))
     DF2$identifier <- rep(id, nrow(DF2))
     
