@@ -51,10 +51,11 @@
 #' endDate <- "2014-10-10"
 #' # These examples require an internet connection to run
 #' rawData <- readNWISuv(siteNumber,parameterCd,startDate,endDate)
-#' 
+#' \dontrun{
 #' timeZoneChange <- readNWISuv(c('04024430','04024000'),parameterCd,
 #'          "2013-11-03","2013-11-03")
-#' firstSite <- timeZoneChange[timeZoneChange$site_no == '04024430',]
+#' }
+#' 
 readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){  
   
   url <- constructNWISURL(siteNumbers,parameterCd,startDate,endDate,"uv",format="xml")
@@ -66,8 +67,7 @@ readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){
 
 #' Reads peak flow data from NWISweb.
 #' 
-#' Reads peak flow from NWISweb. 
-#' Data is retrieved from \url{http://waterdata.usgs.gov/nwis}. 
+#' Reads peak flow from NWISweb. Data is retrieved from \url{http://waterdata.usgs.gov/nwis}. 
 #' 
 #' @param siteNumbers character USGS site number(or multiple sites).  This is usually an 8 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
@@ -100,6 +100,7 @@ readNWISuv <- function (siteNumbers,parameterCd,startDate="",endDate="", tz=""){
 #' comment \tab character \tab Header comments from the RDB file \cr
 #' siteInfo \tab data.frame \tab A data frame containing information on the requested sites \cr
 #' }
+#' @seealso \code{\link{constructNWISURL}}, \code{\link{importRDB1}}
 #' @export
 #' @examples
 #' siteNumbers <- c('01594440','040851325')
@@ -153,6 +154,7 @@ readNWISpeak <- function (siteNumbers,startDate="",endDate=""){
 #'
 #' @note Not all active USGS streamgages have traditional rating curves that
 #'relate flow to stage.
+#' @seealso \code{\link{constructNWISURL}}, \code{\link{importRDB1}}
 #' @export
 #' @examples
 #' siteNumber <- '01594440'
@@ -215,6 +217,7 @@ readNWISrating <- function (siteNumber,type="base"){
 #' comment \tab character \tab Header comments from the RDB file \cr
 #' siteInfo \tab data.frame \tab A data frame containing information on the requested sites \cr
 #' }
+#' @seealso \code{\link{constructNWISURL}}, \code{\link{importRDB1}}
 #' @export
 #' @examples
 #' siteNumbers <- c('01594440','040851325')
@@ -257,41 +260,45 @@ readNWISmeas <- function (siteNumbers,startDate="",endDate="", tz=""){
 #' Name \tab Type \tab Description \cr
 #' agency_cd \tab character \tab The NWIS code for the agency reporting the data\cr
 #' site_no \tab character \tab The USGS site number \cr
-#' dateTime \tab character \tab The date and time of the value as a character \cr 
-#' dateTimeAccuracyCd \tab character \tab Information on the date/time accuracy \cr
-#' censorCode \tab character \tab Censoring information \cr
-#' sourceCode \tab character \tab Information on source of the data \cr
-#' code \tab character \tab Any codes that qualify the corresponding value\cr
-#' value \tab numeric \tab The numeric value for the parameter \cr
+#' site_tp_cd \tab character \tab Site type code \cr 
+#' lev_dt \tab Date \tab Date level measured\cr
+#' lev_tm \tab character \tab Time level measured \cr
+#' lev_tz_cd \tab character \tab Time datum \cr
+#' lev_va \tab numeric \tab Water level value in feet below land surface\cr
+#' sl_lev_va \tab numeric \tab Water level value in feet above specific vertical datum \cr
+#' lev_status_cd \tab character \tab The status of the site at the time the water level was measured \cr
+#' lev_agency_cd \tab character \tab The agency code of the person measuring the water level \cr
 #' }
-#' Note that code and value are repeated for the parameters requested. The names are of the form 
-#' X_D_P_S, where X is literal, 
-#' D is an option description of the parameter, 
-#' P is the parameter code, 
-#' and S is the statistic code (if applicable).
 #' 
 #' There are also several useful attributes attached to the data frame:
 #' \tabular{lll}{
 #' Name \tab Type \tab Description \cr
 #' url \tab character \tab The url used to generate the data \cr
-#' siteInfo \tab data.frame \tab A data frame containing information on the requested sites \cr
-#' variableInfo \tab data.frame \tab A data frame containing information on the requested parameters \cr
-#' statisticInfo \tab data.frame \tab A data frame containing information on the requested statistics on the data \cr
 #' queryTime \tab POSIXct \tab The time the data was returned \cr
+#' comment \tab character \tab Header comments from the RDB file \cr
+#' siteInfo \tab data.frame \tab A data frame containing information on the requested sites \cr
 #' }
 #' 
-#' @seealso \code{\link{renameNWISColumns}}, \code{\link{importWaterML1}}
+#' @seealso \code{\link{constructNWISURL}}, \code{\link{importRDB1}}
 #' @export
 #' @examples
 #' siteNumber <- "434400121275801"
 #' data <- readNWISgwl(siteNumber, '','')
 #' sites <- c("434400121275801", "375907091432201")
 #' data2 <- readNWISgwl(sites, '','')
+#' data3 <- readNWISgwl("420125073193001", '','')
 readNWISgwl <- function (siteNumbers,startDate="",endDate=""){  
   
-  url <- constructNWISURL(siteNumbers,NA,startDate,endDate,"gwlevels",format="wml1")
-  data <- importWaterML1(url,asDateTime=FALSE)
-  data$tz_cd <- NULL
+#   url <- constructNWISURL(siteNumbers,NA,startDate,endDate,"gwlevels",format="wml1")
+#   data <- importWaterML1(url,asDateTime=FALSE)
+#   data$tz_cd <- NULL
+  url <- constructNWISURL(siteNumbers,NA,startDate,endDate,"gwlevels",format="tsv")
+  data <- importRDB1(url,asDateTime=FALSE)
+  data$lev_dt <- as.Date(data$lev_dt)
+  
+  siteInfo <- readNWISsite(siteNumbers)
+  
+  attr(data, "siteInfo") <- siteInfo
   return (data)
 }
 
